/*


    ========== licence begin LGPL
    Copyright (C) 2002 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

package com.sap.dbtech.jdbc.translators;

import java.sql.*;
import com.sap.dbtech.util.*;
/**
 *
 */
public class BinaryStreamTranslator extends StreamTranslator {
    /**
     * AsciiStreamTranslator constructor comment.
     * @param mode int
     * @param ioType int
     * @param dataType int
     * @param len int
     * @param ioLen int
     * @param bufpos int
     */
    protected BinaryStreamTranslator(int mode, int ioType, int dataType, int len, int ioLen, int bufpos) {
        super(mode, ioType, dataType, len, ioLen, bufpos);
    }
    /**
     *
     * @return java.io.InputStream
     * @exception java.sql.SQLException The exception description.
     */
    public java.io.InputStream getBinaryStream (
        SQLParamController controller,
        StructuredMem mem,
        StructuredMem longData) throws SQLException
    {
        return this.getStream (controller, mem, longData);
    }
    /**
     *
     * @return byte []
     */
    public byte [] getBytes (
            SQLParamController controller,
            StructuredMem mem)
        throws SQLException
    {
        java.io.InputStream blobStream;
        java.io.ByteArrayOutputStream tmpStream;

        blobStream = this.getBinaryStream (controller, mem, controller.getReplyData());
        if (blobStream == null) {
            return null;
        }
        try {
            final int bufSizeC = 4096;
            byte [] buf = new byte [bufSizeC];
            int readLen;

            tmpStream = new java.io.ByteArrayOutputStream ();
            readLen = blobStream.read (buf);
            while (readLen > 0) {
                tmpStream.write (buf, 0, readLen);
                if (readLen < bufSizeC) {
                    break;
                }
                readLen = blobStream.read (buf);
            }
        }
        catch (com.sap.dbtech.jdbc.exceptions.StreamIOException sqlExc) {
            throw sqlExc.getSqlException ();
        }
        catch (java.io.IOException ioExc) {
            throw new com.sap.dbtech.jdbc.exceptions.JDBCDriverException (
                ioExc.getMessage (), controller);
        }
        return tmpStream.toByteArray ();
    }
    /**
     *
     * @return java.lang.String
     */
    public Object getObject (
            SQLParamController controller,
            StructuredMem mem)
        throws SQLException
    {
        byte[] tmp = this.getBytes (controller, mem);
        if (tmp == null) {
            tmp = null;
        }
        return tmp;
    }
    /**
     *
     * @return java.io.InputStream
     * @exception java.sql.SQLException The exception description.
     */
    public Object transBinaryStreamForInput (
        java.io.InputStream stream, int length) throws SQLException
    {
        return this.transStreamForInput (stream, length);
    }
}
