/*


    ========== licence begin LGPL
    Copyright (C) 2002 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

package com.sap.dbtech.jdbc.translators;

import java.sql.*;

import com.sap.dbtech.jdbc.packet.*;
import com.sap.dbtech.util.*;

/**
 *
 */
abstract class CharDataTranslator
    extends DBTechTranslator
{
    /**
     * CharDataTranslator constructor comment.
     * @param mode int
     * @param ioType int
     * @param dataType int
     * @param len int
     * @param ioLen int
     * @param bufpos int
     */
    protected CharDataTranslator(
        int mode,
        int ioType,
        int dataType,
        int len,
        int ioLen,
        int bufpos)
    {
        super(mode, ioType, dataType, len, ioLen, bufpos);
    }
    /**
     *
     * @return boolean
     */
    public boolean isCaseSensitive () {
        return true;
    }
    /**
     *
     * @param dataPart com.sap.dbtech.jdbc.packet.DataPart
     * @param data java.lang.Object
     */
    protected void putSpecific (
        DataPart dataPart,
        Object data)
    throws SQLException
    {
        byte [] bytes = StringUtil.bytes_iso8859_1(data.toString()); // ((String) data).getBytes ();
        if (bytes.length > this.physicalLength - 1) {
            throw new com.sap.dbtech.jdbc.exceptions.ValueOverflow (
                com.sap.dbtech.vsp00.DataType.stringValuesC [this.dataType],
                -1);
        }
        dataPart.putInt1 ((byte) ' ', this.bufpos - 1);
        dataPart.putStringBytes (bytes, this.bufpos, this.physicalLength - 1);
    }
    /**
     *
     */
    public Date getDate (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        String strValue = this.getString (controller, mem);
        if (strValue == null) {
            return null;
        }
        try {
            Date dateValue = Date.valueOf (strValue);
            return dateValue;
        }
        catch (IllegalArgumentException dateExc) {
            // ignore and try as time stamp
        }
        try {
            Timestamp tsValue = Timestamp.valueOf (strValue);
            return new Date (tsValue.getTime ());
        }
        catch (IllegalArgumentException tsExc) {
            throw newParseException (strValue, "Date");
        }
    }
    /**
     *
     */
    public Time getTime (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        String strValue = this.getString (controller, mem);
        if (strValue == null) {
            return null;
        }
        try {
            Time dateValue = Time.valueOf (strValue);
            return dateValue;
        }
        catch (IllegalArgumentException dateExc) {
            throw newParseException (strValue, "Time");
        }
    }
    /**
     *
     */
    public Timestamp getTimestamp (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        String strValue = this.getString (controller, mem);
        if (strValue == null) {
            return null;
        }
        try {
            Timestamp tsValue = Timestamp.valueOf (strValue);
            return tsValue;
        }
        catch (IllegalArgumentException tsExc) {
            // ignore and try as date
        }
        try {
            Date dateValue = Date.valueOf (strValue);
            return new Timestamp (dateValue.getTime ());
        }
        catch (IllegalArgumentException dateExc) {
            throw newParseException (strValue, "Timestamp");
        }
    }
}
