/*


    ========== licence begin LGPL
    Copyright (C) 2002 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/

package com.sap.dbtech.jdbc.translators;

import java.sql.*;
import com.sap.dbtech.util.*;
/**
 *
 */
class DateTranslator extends CharDataTranslator {
    public static final String zeroPadC = "0000";
    /**
     * DateTranslator constructor comment.
     * @param mode int
     * @param ioType int
     * @param len int
     * @param ioLen int
     * @param bufpos int
     */
    protected DateTranslator(int mode, int ioType, int dataType, int len, int ioLen, int bufpos) {
        super(mode, ioType, dataType, len, ioLen, bufpos);
    }
    /**
     *
     * @return java.sql.Date
     */
    public Date getDate (
        SQLParamController controller,
        StructuredMem mem) throws SQLException
    {
        String raw;
        Date result = null;

        if (!this.isNull (controller, mem)) {
            raw = mem.getString(this.bufpos, this.physicalLength - 1);
            try {
                result = Date.valueOf (raw);
            }
            catch (IllegalArgumentException exc) {
                throw this.newParseException (raw, "Date");
            }
        }
        return result;
    }
    /**
     *
     * @return java.sql.Date
     */
    public Object getObject (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        return this.getDate (controller, mem);
    }
    /**
     *
     */
    public Timestamp getTimestamp (
        SQLParamController controller,
        StructuredMem mem)
    throws SQLException
    {
        Date dateValue = this.getDate (controller, mem);
        if (dateValue == null) {
            return null;
        }
        return new Timestamp (dateValue.getTime ());
    }
    /**
     *
     * @return boolean
     */
    public boolean isCaseSensitive () {
        return false;
    }
    /**
     *
     * @param newValue java.sql.Date
     */
    public Object transDateForInput (Date arg)
    throws java.sql.SQLException {
        if (arg == null) {
            return null;
        }
        else {
            String result = arg.toString ();
            int lenDiff = this.logicalLength - result.length ();
            if (lenDiff > 0) {
                result = zeroPadC.substring (0, lenDiff) + result;
            }
            return result;
        }
    }
    /**
     *
     * @param obj java.lang.Object
     */
    public Object transSpecificForInput (Object obj)
    throws SQLException
    {
        Object result = null;

        if (obj instanceof Date) {
            result = this.transDateForInput ((Date) obj);
        }
        return result;
    }
    /**
     *
     * @param val java.lang.String
     */
    public Object transStringForInput (String val)
    throws SQLException
    {
        if (val == null) {
            return null;
        }
        try {
            return this.transDateForInput (Date.valueOf (val));
        }
        catch (IllegalArgumentException exc) {
            // ignore, try timestamp
        }
        try {
            Timestamp ts = Timestamp.valueOf (val);
            return this.transDateForInput (new Date (ts.getTime ()));
        }
        catch (IllegalArgumentException exc) {
            // possibly: try other parsing strategies
        }
        throw this.newParseException (val, "Date");
    }
}